@@ -37,6 +37,7 @@ class InfiniteTimeSeries:
         self._data = seed_data.loc[:, ["timestamp", "value"]]
         self._data.set_index("timestamp", inplace=True)
         self._data.index = pd.to_datetime(self._data.index)
+        self._data = self._data.asfreq(frequency, method="ffill")
         self._data = self._data.resample(frequency).interpolate(method='spline', order=3)
         self._data = self._data.iloc[0:min(self._get_intervals_per_year(frequency), len(self._data))]
         self._data.index = self._index_to_interval_of_year(self._data.index, frequency)
@@ -46,8 +47,8 @@ class InfiniteTimeSeries:
         rounded_index = index.floor(self._frequency)
         index_day_of_year = rounded_index.timetuple().tm_yday
         index_interval_of_year = index_day_of_year * self._from_days_map[self._frequency] + self._datetime_projections[self._frequency](rounded_index)
-        row = self._data.loc[index_interval_of_year]
-        return rounded_index, row.value
+        row = self[index_interval_of_year]
+        return rounded_index, row
 
     def _get_intervals_per_year(self, frequency: str) -> int:
         return 365 * self._from_days_map[frequency]
